==> zhongyan-manage-service-api-yyjh-02-20220924.091337-13-sources.jar: cn/com/duiba/cloud/manage/service/api/model/enums/RedisKeyEnum.java <==
package cn.com.duiba.cloud.manage.service.api.model.enums;

import cn.hutool.core.util.StrUtil;

/**
 * @author yuanzhixin
 * @version 1.0
 * @description redis key
 * @date 2021/11/8 11:20
 */
public enum RedisKeyEnum {

    /**
     * 企业相关
     */
    FIRST_LOGIN("首次登录", "DUIBA_MANAGE_SERVICE:FIRST_LOGIN"),
    CAPTCHA("图片验证码", "DUIBA_MANAGE_SERVICE:CAPTCHA"),
    LAST_LOGIN("上次登录", "DUIBA_MANAGE_SERVICE:LAST_LOGIN"),
    TENANT_STAFF_REL("企业内员工关系", "DUIBA_MANAGE_SERVICE:TENANT_STAFF_REL:{}_{}"),

    /* 角色相关 */

    UNIQUE_TENANT_ROLE_NAME("企业下角色名称唯一", "DUIBA_MANAGE_SERVICE:TB_ROLE:{}_{}"),
    UNIQUE_TENANT_NAME("企业名称唯一", "DUIBA_MANAGE_SERVICE:TB_TENANT:{}"),
    UNIQUE_DEPT_NAME("部门名称唯一", "DUIBA_MANAGE_SERVICE:TB_DEPT:{}"),

    /* 信息相关*/
    SYNC_MATERIAL("同步微信素材","DUIBA_MANAGE_SERVICE:SYNC_MATERIAL:{}"),
    COUNT_TAG_VALUE_USER("计算标签值关联人数","DUIBA_MANAGE_SERVICE: COUNT_TAG_VALUE_USER"),
    COUNT_TAG_GROUP_USER("计算标签用户群关联人数","COUNT_TAG_GROUP_USER"),

    PUBLISH_PAGE("发布页面","DUIBA_MANAGE_SERVICE:PUBLISH_PAGE:{}"),

    /*es同步相关*/
    ES_CLEAR_TEMPLETE("删除es索引","DUIBA_MANAGE_SERVICE:CLEAR_TEMPLETE:{}"),
    ES_PAGE_STATISTICS("页面数据统计","DUIBA_MANAGE_SERVICE:PAGE_STATISTICS:{}"),
    ES_UNIT_STATISTICS("组件数据统计","DUIBA_MANAGE_SERVICE:UNIT_STATISTICS:{}"),

    RETAILER_ENTER_JOB("同步零售户入网锁", "DUIBA_MANAGE_SERVICE:RETAILER_ENTER_JOB"),

    /** 个人信息相关 */
    CONSUMER_INFO_CHANGE_SORT("修改个人信息顺序", "DUIBA_MANAGE_SERVICE:CONSUMER_INFO_CHANGE_SORT"),
    CONSUMER_INFO_SAVE("保存个人信息", "DUIBA_MANAGE_SERVICE:CONSUMER_INFO_SAVE:{}"),

    /**
     * 心中的远方活动相关
     */
    PEACE_REMAIN_REPORT("计算平和星余额","DUIBA_MANAGE_SERVICE:PEACE_REMAIN_REPORT_KEY"),

    USER_VIEW_REPORT("时段独立访客数","DUIBA_MANAGE_SERVICE:USER_VIEW_REPORT_KEY"),

    /**
     * 心中的远方活动专属
     */
    ACTIVITY_JOIN_STATISTICS_KEY("活动参与报表","DUIBA_ACTIVITY_JOIN_STATISTICS_KEY:{}_{}"),
    ACTIVITY_TASK_STATISTICS_KEY("活动任务报表","DUIBA_ACTIVITY_TASK_STATISTICS_KEY:{}_{}"),
    ACTIVITY_PRIZE_STATISTICS_KEY("活动奖品报表","DUIBA_  ACTIVITY_PRIZE_STATISTICS_KEY:{}_{}"),
    ACTIVITY_TODAY_ASS_STATISTICS_KEY("活动当天10，16点数据统计","DUIBA_ ACTIVITY_TODAY_ASS_STATISTICS_PRE_KEY:{}_{}"),

    ACTIVITY_PLAN_TEMPLATE_KEY("活动计划版块", "DUIBA_MANAGE_SERVICE:ACTIVITY_PLAN_TEMPLATE_KEY"),


;

    private final String desc;
    private final String template;

    RedisKeyEnum(String desc, String template) {
        this.desc = desc;
        this.template = template;
    }

    public static String getRedisKey(RedisKeyEnum keyTemplate, Object... args) {
        return StrUtil.format(keyTemplate.template, args);
    }
}

==> zhongyan-manage-service-api-yyjh-02-20221010.025815-23-sources.jar: cn/com/duiba/cloud/manage/service/api/model/enums/RedisKeyEnum.java <==
package cn.com.duiba.cloud.manage.service.api.model.enums;

import cn.hutool.core.util.StrUtil;

/**
 * @author yuanzhixin
 * @version 1.0
 * @description redis key
 * @date 2021/11/8 11:20
 */
public enum RedisKeyEnum {

    /**
     * 企业相关
     */
    FIRST_LOGIN("首次登录", "DUIBA_MANAGE_SERVICE:FIRST_LOGIN"),
    CAPTCHA("图片验证码", "DUIBA_MANAGE_SERVICE:CAPTCHA"),
    LAST_LOGIN("上次登录", "DUIBA_MANAGE_SERVICE:LAST_LOGIN"),
    TENANT_STAFF_REL("企业内员工关系", "DUIBA_MANAGE_SERVICE:TENANT_STAFF_REL:{}_{}"),

    /* 角色相关 */

    UNIQUE_TENANT_ROLE_NAME("企业下角色名称唯一", "DUIBA_MANAGE_SERVICE:TB_ROLE:{}_{}"),
    UNIQUE_TENANT_NAME("企业名称唯一", "DUIBA_MANAGE_SERVICE:TB_TENANT:{}"),
    UNIQUE_DEPT_NAME("部门名称唯一", "DUIBA_MANAGE_SERVICE:TB_DEPT:{}"),

    /* 信息相关*/
    SYNC_MATERIAL("同步微信素材","DUIBA_MANAGE_SERVICE:SYNC_MATERIAL:{}"),
    COUNT_TAG_VALUE_USER("计算标签值关联人数","DUIBA_MANAGE_SERVICE: COUNT_TAG_VALUE_USER"),
    COUNT_TAG_GROUP_USER("计算标签用户群关联人数","COUNT_TAG_GROUP_USER"),

    PUBLISH_PAGE("发布页面","DUIBA_MANAGE_SERVICE:PUBLISH_PAGE:{}"),

    /*es同步相关*/
    ES_CLEAR_TEMPLETE("删除es索引","DUIBA_MANAGE_SERVICE:CLEAR_TEMPLETE:{}"),
    ES_PAGE_STATISTICS("页面数据统计","DUIBA_MANAGE_SERVICE:PAGE_STATISTICS:{}"),
    ES_UNIT_STATISTICS("组件数据统计","DUIBA_MANAGE_SERVICE:UNIT_STATISTICS:{}"),

    RETAILER_ENTER_JOB("同步零售户入网锁", "DUIBA_MANAGE_SERVICE:RETAILER_ENTER_JOB"),

    /** 个人信息相关 */
    CONSUMER_INFO_CHANGE_SORT("修改个人信息顺序", "DUIBA_MANAGE_SERVICE:CONSUMER_INFO_CHANGE_SORT"),
    CONSUMER_INFO_SAVE("保存个人信息", "DUIBA_MANAGE_SERVICE:CONSUMER_INFO_SAVE:{}"),

    /**
     * 心中的远方活动相关
     */
    PEACE_REMAIN_REPORT("计算平和星余额","DUIBA_MANAGE_SERVICE:PEACE_REMAIN_REPORT_KEY"),

    USER_VIEW_REPORT("时段独立访客数","DUIBA_MANAGE_SERVICE:USER_VIEW_REPORT_KEY"),

    /**
     * 心中的远方活动专属
     */
    ACTIVITY_JOIN_STATISTICS_KEY("活动参与报表","DUIBA_ACTIVITY_JOIN_STATISTICS_KEY:{}_{}"),
    ACTIVITY_TASK_STATISTICS_KEY("活动任务报表","DUIBA_ACTIVITY_TASK_STATISTICS_KEY:{}_{}"),
    ACTIVITY_PRIZE_STATISTICS_KEY("活动奖品报表","DUIBA_  ACTIVITY_PRIZE_STATISTICS_KEY:{}_{}"),
    ACTIVITY_TODAY_ASS_STATISTICS_KEY("活动当天10，16点数据统计","DUIBA_ ACTIVITY_TODAY_ASS_STATISTICS_PRE_KEY:{}_{}"),

    ACTIVITY_PLAN_TEMPLATE_KEY("活动计划版块", "DUIBA_MANAGE_SERVICE:ACTIVITY_PLAN_TEMPLATE_KEY"),
    ACTIVITY_PLAN_TEMPLATE_REMOVE_KEY("活动计划版块移动","DUIBA_MANAGE_SERVICE:ACTIVITY_PLAN_TEMPLATE_REMOVE_KEY")


;

    private final String desc;
    private final String template;

    RedisKeyEnum(String desc, String template) {
        this.desc = desc;
        this.template = template;
    }

    public static String getRedisKey(RedisKeyEnum keyTemplate, Object... args) {
        return StrUtil.format(keyTemplate.template, args);
    }
}
